@@ -1,3 +1,5 @@
+import numpy as np
+
 class Profile:
     """Profile of voters' preferences"""
 
@@ -12,7 +14,7 @@ class Profile:
             candidates = []
         if preferences is None:
             preferences = []
-        self.candidates = candidates[:]
+        self.candidates = candidates
         self.num_cand = len(candidates)
         self.preferences = preferences
         self.scores = {}
